@@ -23,9 +23,10 @@ import logging
 import argparse
 
 from bs4 import BeautifulSoup
-from typing import Union, Generator
 from functools import cached_property
+from typing import Union, Generator, Optional
 from base_api.base import BaseCore, setup_logger
+from base_api.modules.config import RuntimeConfig
 
 try:
     from modules.consts import *
@@ -39,7 +40,7 @@ except (ModuleNotFoundError, ImportError):
 
 
 class Video:
-    def __init__(self, url, core=None):
+    def __init__(self, url, core: Optional[BaseCore] = None):
         """
         :param url: (str) The URL of the video
         """
@@ -58,7 +59,7 @@ class Video:
         self.quality_url_map = None
         self.available_qualities = None
 
-    def enable_logging(self, log_file: str = None, level = None, log_ip=None, log_port=None):
+    def enable_logging(self, log_file: str = None, level = None, log_ip: str = None, log_port: int = None):
         self.logger = setup_logger(name="XVIDEOS API - [Video]", log_file=log_file, level=level, http_ip=log_ip, http_port=log_port)
 
     @classmethod
@@ -128,20 +129,23 @@ class Video:
         segments = self.core.get_segments(quality=quality, m3u8_url_master=self.m3u8_base_url)
         return segments
 
-    def download(self, downloader, quality, path="./", callback=None, no_title=False) -> bool:
+    def download(self, downloader, quality, path="./", callback=None, no_title=False, remux: bool = False, callback_remux=None) -> bool:
         """
         :param callback:
         :param downloader:
         :param quality:
         :param path:
         :param no_title:
+        :param remux:
+        :param callback_remux:
         :return:
         """
         if not no_title:
             path = os.path.join(path, f"{self.title}.mp4")
 
         try:
-            self.core.download(video=self, quality=quality, path=path, callback=callback, downloader=downloader)
+            self.core.download(video=self, quality=quality, path=path, callback=callback, downloader=downloader,
+                               remux=remux, callback_remux=callback_remux)
             return True
 
         except AttributeError:
@@ -228,7 +232,7 @@ class Video:
         pornstars = self.soup.find_all('li', class_="model")
         urls = []
         for pornstar in pornstars:
-            urls.append(f"https://xvideos.com{pornstar.next["href"]}")
+            urls.append(f"https://xvideos.com{pornstar.next['href']}")
 
         for url in urls:
             yield Pornstar(url=url, core=self.core)
@@ -249,7 +253,7 @@ class Channel:
     different things.
 
     """
-    def __init__(self, url: str, core: BaseCore):
+    def __init__(self, url: str, core: Optional[BaseCore]):
         self.core = core
         self.logger = setup_logger(name="XVIDEOS API - [Channel]", log_file=None, level=logging.ERROR)
         self.url = self.check_url(url)
@@ -258,7 +262,7 @@ class Channel:
         self.bs4_about_me = BeautifulSoup(about_me_html, "html.parser")
         self.data = json.loads(base_content)
 
-    def enable_logging(self, name="XVIDEOS API - [Channel]", log_file=None, level=logging.DEBUG, log_ip=None, log_port=None):
+    def enable_logging(self, name="XVIDEOS API - [Channel]", log_file=None, level=logging.DEBUG, log_ip: str = None, log_port: int = None):
         self.logger = setup_logger(name=name, log_file=log_file, level=level, http_ip=log_ip, http_port=log_port)
 
     def check_url(self, url: str) -> str:
@@ -340,7 +344,7 @@ class Channel:
 
 
 class Pornstar:
-    def __init__(self, url: str, core: BaseCore):
+    def __init__(self, url: str, core: Optional[BaseCore]):
         self.core = core
         self.url = self.check_url(url)
         base_content = self.core.fetch(f"{self.url}/videos/best/0")
@@ -349,7 +353,7 @@ class Pornstar:
         self.data = json.loads(base_content)
         self.logger = setup_logger(name="XVIDEOS API - [Pornstar]", log_file=None, level=logging.ERROR)
 
-    def enable_logging(self, log_file: str = None, level=None, log_ip=None, log_port=None):
+    def enable_logging(self, log_file: str = None, level=None, log_ip: str = None, log_port: int = None):
         self.logger = setup_logger(name="XVIDEOS API - [Pornstar]", log_file=log_file, level=level, http_ip=log_ip, http_port=log_port)
 
     def check_url(self, url):
@@ -454,11 +458,12 @@ class Pornstar:
 
 
 class Client:
-    def __init__(self, core=None):
-        self.core = core or BaseCore()
+    def __init__(self, core: Optional[BaseCore] = None):
+        self.core = core or BaseCore(config=RuntimeConfig())
+        self.core.initialize_session(headers)
         self.logger = setup_logger(name="XVIDEOS API - [Client]", log_file=None, level=logging.ERROR)
 
-    def enable_logging(self, log_file: str = None, level=None, log_ip=None, log_port=None):
+    def enable_logging(self, log_file: str = None, level=None, log_ip: str = None, log_port: int = None):
         self.logger = setup_logger(name="XVIDEOS API - [Client]", log_file=log_file, level=level, http_ip=log_ip, http_port=log_port)
 
     def get_video(self, url: str) -> Video:
